pub struct GetBlockchainInfo {
pub chain: String,
pub blocks: u32,
pub headers: u32,
pub bestblockhash: BlockHash,
pub difficulty: f64,
pub verificationprogress: f64,
pub initialblockdownload: bool,
pub chainwork: String,
pub size_on_disk: u64,
pub pruned: bool,
pub warnings: Vec<String>,
}Expand description
Response for getblockchaininfo RPC.
Fields
chain: StringCurrent network name (main, test, signet, regtest).
blocks: u32The current number of blocks processed in the server.
headers: u32The current number of headers we have validated.
bestblockhash: BlockHashThe hash of the currently best block.
difficulty: f64The current difficulty.
verificationprogress: f64Estimate of verification progress [0..1].
initialblockdownload: boolWhether initial block download is complete.
chainwork: StringTotal amount of work in active chain, in hexadecimal.
size_on_disk: u64The estimated size of the block and undo files on disk.
pruned: boolIf the blocks are subject to pruning.
warnings: Vec<String>Any network and blockchain warnings.