pub struct GetMempoolEntry {Show 17 fields
pub vsize: u64,
pub weight: u64,
pub fee: f64,
pub modifiedfee: f64,
pub time: i64,
pub height: u32,
pub descendantcount: u64,
pub descendantsize: u64,
pub descendantfees: u64,
pub ancestorcount: u64,
pub ancestorsize: u64,
pub ancestorfees: u64,
pub wtxid: Txid,
pub depends: Vec<Txid>,
pub spentby: Vec<Txid>,
pub bip125_replaceable: bool,
pub unbroadcast: bool,
}Expand description
Response for getmempoolentry RPC.
Fields
vsize: u64Virtual transaction size.
weight: u64Transaction weight.
fee: f64Transaction fee in BTC.
modifiedfee: f64Transaction fee with fee deltas used for mining priority in BTC.
time: i64Local time transaction entered pool in seconds since 1 Jan 1970 GMT.
height: u32Block height when transaction entered pool.
descendantcount: u64Number of in-mempool descendant transactions (including this one).
descendantsize: u64Virtual transaction size of in-mempool descendants (including this one).
descendantfees: u64Modified fees of in-mempool descendants (including this one) in BTC.
ancestorcount: u64Number of in-mempool ancestor transactions (including this one).
ancestorsize: u64Virtual transaction size of in-mempool ancestors (including this one).
ancestorfees: u64Modified fees of in-mempool ancestors (including this one) in BTC.
wtxid: TxidHash of serialized transaction, including witness data.
depends: Vec<Txid>Unconfirmed transactions used as inputs for this transaction.
spentby: Vec<Txid>Unconfirmed transactions spending outputs from this transaction.
bip125_replaceable: boolWhether this transaction could be replaced due to BIP125.
unbroadcast: boolWhether this transaction is currently unbroadcast.