pub struct GetMempoolInfo {
pub loaded: bool,
pub size: u64,
pub bytes: u64,
pub usage: u64,
pub total_fee: f64,
pub maxmempool: u64,
pub mempoolminfee: f64,
pub minrelaytxfee: f64,
pub incrementalrelayfee: f64,
pub unbroadcastcount: u64,
pub fullrbf: bool,
}Expand description
Response for getmempoolinfo RPC.
Fields
loaded: boolTrue if the mempool is fully loaded.
size: u64Current tx count.
bytes: u64Sum of all virtual transaction sizes.
usage: u64Total memory usage for the mempool.
total_fee: f64Total fees for all transactions in the mempool in BTC.
maxmempool: u64Maximum memory usage for the mempool.
mempoolminfee: f64Minimum fee rate in BTC/kvB for tx to be accepted.
minrelaytxfee: f64Current minimum relay fee for transactions.
incrementalrelayfee: f64Minimum fee rate increment for mempool limiting or replacement in BTC/kvB.
unbroadcastcount: u64Current number of transactions that haven’t passed initial broadcast yet.
fullrbf: boolTrue if mempool accepts RBF without signaling inspection.