Trait NetworkApiServer

pub trait NetworkApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required method
    fn get_network_info(&self) -> Result<GetNetworkInfo, Error>;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the NetworkApi RPC API.

Required Methods

fn get_network_info(&self) -> Result<GetNetworkInfo, Error>

Returns an object containing various state info regarding P2P networking.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors